@@ -1,7 +1,7 @@
 package Data::Clean::Base;
 
-our $DATE = '2015-06-10'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $DATE = '2016-01-20'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010;
 use strict;
@@ -182,11 +182,11 @@ sub _generate_cleanser_code {
         my @args = @$circ; shift @args;
         my $act = $self->$meth(\@args);
         #$add_stmt->('stmt', 'say "ref=$ref, " . {{var}}'); # DEBUG
-        $add_new_if->('$ref && $refs{ {{var}} }++', $act);
+        $add_if->('$ref && $refs{ {{var}} }++', $act);
     }
 
     # recurse array and hash
-    $add_new_if_ref->("ARRAY", '$process_array->({{var}})');
+    $add_if_ref->("ARRAY", '$process_array->({{var}})');
     $add_if_ref->("HASH" , '$process_hash->({{var}})');
 
     # lastly, catch any reference left
@@ -253,7 +253,7 @@ Data::Clean::Base - Base class for Data::Clean::*
 
 =head1 VERSION
 
-This document describes version 0.28 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2015-06-10.
+This document describes version 0.29 of Data::Clean::Base (from Perl distribution Data-Clean-JSON), released on 2016-01-20.
 
 =for Pod::Coverage ^(command_.+)$
 
@@ -291,18 +291,18 @@ This will replace a reference like C<{}> with C<HASH>.
 
 This will replace a reference like C<{}> with I<STR>.
 
-=item * ['call_method']
+=item * ['call_method' => STR]
 
-This will call a method and use its return as the replacement. For example:
-DateTime->from_epoch(epoch=>1000) when processed with [call_method => 'epoch']
-will become 1000.
+This will call a method named I<STR> and use its return as the replacement. For
+example: C<< DateTime->from_epoch(epoch=>1000) >> when processed with C<<
+[call_method => 'epoch'] >> will become 1000.
 
 =item * ['call_func', STR]
 
-This will call a function named STR with value as argument and use its return as
-the replacement.
+This will call a function named I<STR> with value as argument and use its return
+as the replacement.
 
-=item * ['one_or_zero', STR]
+=item * ['one_or_zero']
 
 This will perform C<< $val ? 1:0 >>.
 
@@ -317,7 +317,7 @@ Should be done only for objects (C<-obj>).
 
 =item * ['code', STR]
 
-This will replace with STR treated as Perl code.
+This will replace with I<STR> treated as Perl code.
 
 =item * ['clone', INT]
 
@@ -404,7 +404,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
